/**
 * An interface specifying the operations that should be supported
 * by a queue abstract data type.
 * Queues are worklists where the items are removed in the order
 * they are added. I.e., they implement a FIFO logic.
 *
 * @author Rui Meireles
 * @version 1.0
 */
public interface MyQueue<E> extends MyWorklist<E>{
    
    
    /**
     * Adds a new element to the queue. Is a synonym for add(E elem).
     * 
     * @param elem the element to be enqueued.
     * @return true if the collection changed as a result of this addition;
     * false otherwise.
     */
    public boolean enqueue(E elem);
    
    
    /**
     * Removes the next item to be removed from the queue, 
     * according to its removal rule.
     * Is a synonym for remove().
     * 
     * @return the item removed, or null if queue is empty.
     */
    public E dequeue();
}
