import static org.junit.Assert.*;
import org.junit.Test;
import org.junit.FixMethodOrder;
import org.junit.runners.MethodSorters;

/**
 * A class with unit tests for a MyQueue queue implementation.
 * It tests the MyQueueMyLinkedList class but is designed to be able to
 * be extended for testing other MyQueue implementations.
 * For that, subclasses need only override the createEmptyLongQueue() 
 * method.
 *
 * The tests try to test all methods and corner cases.
 * We recommend you tackle them (i.e. try to make them pass) in the 
 * order they appear in this file.
 *
 * @author  Rui Meireles
 * @version 1.0
 */
@FixMethodOrder(MethodSorters.NAME_ASCENDING)
public class MyQueueMyLinkedListTest extends AMyCollectionTest{

    protected MyCollection<Long> createEmptyLongCollection(){
        return createEmptyLongQueue();
    }

    /**
     * A factory method to create an empty queue of long integers using the 
     * implementation of MyQueue we're trying to test.
     * 
     * @return an empty long list of integers.
     */
    protected MyQueue<Long> createEmptyLongQueue(){
        return new MyQueueMyLinkedList<Long>();
    }

    /**
     * Tests whether the queue removal order is respected.
     * Assumes correctness of the following methods: add(), size().
     */
    @Test
    public void testQueue1AddAndRemove(){
        MyQueue<Long> queue = createEmptyLongQueue(); // new empty list        
        this.addNints(queue, NINTS); // add some values

        // remove items and check the order
        for (long i=0; i < NINTS; i++){
            assertEquals("Queue remove does not implement FIFO semantics", i, (long)queue.remove());
            assertEquals("Queue remove does not change size", NINTS-1-i, queue.size());
        }  
        assertEquals("Queue remove from empty queue doesn't yield null", null, queue.remove());
    }
}