/**
 * An interface specifying the operations that should be supported
 * by a stack abstract data type.
 * Stacks are worklists where the items are removed in reverse
 * order of addition. I.e., they implement a LIFO logic.
 *
 * @author Rui Meireles
 * @version 1.0
 */
public interface MyStack<E> extends MyWorklist<E>{
    
    
    /**
     * Pushes a new element onto the stack.
     * This method is a synonym for add(E elem).
     * 
     * @param elem the element to be pushed.
     * @return true if the collection changed as a result of this addition; 
     * false otherwise.
     */
    public boolean push(E elem);
    
    
    /**
     * Pops the next item to be removed out from the stack, 
     * according to its removal rule.
     * This method is a synonym for remove().
     * 
     * @return the item removed, or null if queue is empty.
     */
    public E pop();
}
