import static org.junit.Assert.*;
import org.junit.Test;
import org.junit.FixMethodOrder;
import org.junit.runners.MethodSorters;

/**
 * A class with unit tests for a MyStack queue implementation.
 * It tests the MyStackMyArrayList class but is designed to be able to
 * be extended for testing other MyStack implementations.
 * For that, subclasses need only override the createEmptyLongStack() 
 * method.
 *
 * The tests try to test all methods and corner cases.
 * We recommend you tackle them (i.e. try to make them pass) in the 
 * order they appear in this file.
 *
 * @author  Rui Meireles
 * @version 1.0
 */
@FixMethodOrder(MethodSorters.NAME_ASCENDING)
public class MyStackMyLinkedListTest extends AMyCollectionTest{

    protected MyCollection<Long> createEmptyLongCollection(){
        return createEmptyLongStack();
    }

    /**
     * A factory method to create an empty stack of long integers using the 
     * implementation of MyStack we're trying to test.
     * 
     * @return an empty long list of integers.
     */
    protected MyStack<Long> createEmptyLongStack(){
        return new MyStackMyLinkedList<Long>();
    }

    /**
     * Tests whether the queue removal order is respected.
     * Assumes correctness of the following methods: add(), size().
     */
    @Test
    public void testStack1AddAndRemove(){
        MyStack<Long> stack = createEmptyLongStack(); // new empty list        
        this.addNints(stack, NINTS); // add some values

        // remove items and check the order
        for (long i=NINTS-1; i >=0; i--){
            assertEquals("Stack remove does not implement LIFO semantics", i, (long)stack.remove());
            assertEquals("Stack remove does not change size", i, stack.size());
        }  
        assertEquals("Stack remove from empty stack doesn't yield null", null, stack.remove());
    }
}